@@ -77,8 +77,6 @@
 /* 10 */
 /***/ (function(module, exports, __webpack_require__) {
 
-/*globals wp */
-
 var media = wp.media;
 
 media.controller.EditAttachmentMetadata = __webpack_require__( 11 );
@@ -96,8 +94,6 @@ media.view.DeleteSelectedPermanentlyButton = __webpack_require__( 19 );
 /* 11 */
 /***/ (function(module, exports) {
 
-/*globals wp */
-
 /**
  * wp.media.controller.EditAttachmentMetadata
  *
@@ -130,8 +126,6 @@ module.exports = EditAttachmentMetadata;
 /* 12 */
 /***/ (function(module, exports) {
 
-/*globals wp, _, Backbone */
-
 /**
  * wp.media.view.MediaFrame.Manage
  *
@@ -173,7 +167,7 @@ Manage = MediaFrame.extend({
 		this.$window = $( window );
 		this.$adminBar = $( '#wpadminbar' );
 		this.$window.on( 'scroll resize', _.debounce( _.bind( this.fixPosition, this ), 15 ) );
-		$( document ).on( 'click', '.add-new-h2', _.bind( this.addNewClickHandler, this ) );
+		$( document ).on( 'click', '.page-title-action', _.bind( this.addNewClickHandler, this ) );
 
 		// Ensure core and media grid view UI is enabled.
 		this.$el.addClass('wp-core-ui');
@@ -404,8 +398,6 @@ module.exports = Manage;
 /* 13 */
 /***/ (function(module, exports) {
 
-/*globals wp */
-
 /**
  * wp.media.view.Attachment.Details.TwoColumn
  *
@@ -453,8 +445,6 @@ module.exports = TwoColumn;
 /* 14 */
 /***/ (function(module, exports) {
 
-/*globals wp, Backbone */
-
 /**
  * wp.media.view.MediaFrame.Manage.Router
  *
@@ -507,8 +497,6 @@ module.exports = Router;
 /* 15 */
 /***/ (function(module, exports) {
 
-/*globals wp, _ */
-
 /**
  * wp.media.view.EditImage.Details
  *
@@ -548,8 +536,6 @@ module.exports = Details;
 /* 16 */
 /***/ (function(module, exports) {
 
-/*globals wp, _, jQuery */
-
 /**
  * wp.media.view.MediaFrame.EditAttachments
  *
@@ -797,8 +783,6 @@ module.exports = EditAttachments;
 /* 17 */
 /***/ (function(module, exports) {
 
-/*globals wp */
-
 /**
  * wp.media.view.SelectModeToggleButton
  *
@@ -814,6 +798,10 @@ var Button = wp.media.view.Button,
 
 SelectModeToggle = Button.extend({
 	initialize: function() {
+		_.defaults( this.options, {
+			size : ''
+		} );
+
 		Button.prototype.initialize.apply( this, arguments );
 		this.listenTo( this.controller, 'select:activate select:deactivate', this.toggleBulkEditHandler );
 		this.listenTo( this.controller, 'selection:action:done', this.back );
@@ -845,16 +833,22 @@ SelectModeToggle = Button.extend({
 
 		// TODO: the Frame should be doing all of this.
 		if ( this.controller.isModeActive( 'select' ) ) {
-			this.model.set( 'text', l10n.cancelSelection );
-			children.not( '.media-button' ).hide();
+			this.model.set( {
+				size: 'large',
+				text: l10n.cancelSelection
+			} );
+			children.not( '.spinner, .media-button' ).hide();
 			this.$el.show();
 			toolbar.$( '.delete-selected-button' ).removeClass( 'hidden' );
 		} else {
-			this.model.set( 'text', l10n.bulkSelect );
+			this.model.set( {
+				size: '',
+				text: l10n.bulkSelect
+			} );
 			this.controller.content.get().$el.removeClass( 'fixed' );
 			toolbar.$el.css( 'width', '' );
 			toolbar.$( '.delete-selected-button' ).addClass( 'hidden' );
-			children.not( '.spinner, .media-button' ).show();
+			children.not( '.media-button' ).show();
 			this.controller.state().get( 'selection' ).reset();
 		}
 	}
@@ -867,8 +861,6 @@ module.exports = SelectModeToggle;
 /* 18 */
 /***/ (function(module, exports) {
 
-/*globals wp */
-
 /**
  * wp.media.view.DeleteSelectedButton
  *
@@ -926,8 +918,6 @@ module.exports = DeleteSelected;
 /* 19 */
 /***/ (function(module, exports) {
 
-/*globals wp */
-
 /**
  * wp.media.view.DeleteSelectedPermanentlyButton
  *
